==> libreoffice-still-sdk-24.8.7-4-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/a00311.js <==
var a00311 =
[
    [ "cppu::UnoType< T >", "a01014.html", "a01014" ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a2a5e69a5a7c20b9675e7de52c674c74f", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a484a7f1ab147ff31d905fe25043ba927", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a02973029e5803f67e2f505db228f1800", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a8e9a83dbbdbe424b9e026ad4c94c79f3", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a08bcf546041af2abc08b1cc0a6e4a28e", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a8870b802ccf2d3760fd691f704a3c88b", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a8fdad5e906b1a6418a0d12df6a0cb447", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#abc66fa74095803f4c99f09cecec9fb11", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a2e9866b0e88e1ef623545f3c20509d81", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a980ac7c01ad8ee65a3ca5134957429f0", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a04eacc9c558d87087af3dd42a62f8aa1", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a3d68cd6a0dce2d1e13b59d4d02f3f0af", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#acf4ffa893ccd35be9b49c4c49dce7ca8", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a46d524c85268a20f98e56d7b0a923389", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a2d3a5b37a84942d51f91f48f49e957db", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#ad86b73560eae9fe41657992fb3931b18", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a728d989cc756ae6108398cfdc57488ab", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a6d93904d90e786a200012ad5c44ba2ad", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a9407c7520634f54fe5972ffcdff3ec64", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a01be54634084231c8a8d42a35bc11bbd", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a900a714bf1977628240aecbe89284c4e", null ],
    [ "cppu::getTypeFavourUnsigned", "a00537.html#a537248b31d476a5a671ecf9e175cb99e", null ],
    [ "cppu::getTypeFavourUnsigned", "a00537.html#a88763f57277570861901089a48dbfffe", null ],
    [ "cppu::getTypeFavourUnsigned", "a00537.html#a58d960508ebd9effe3f954872ec2ebaf", null ],
    [ "cppu::detail::getTypeFromTypeClass", "a00541.html#acb58f90e3da82a306b5eb7d4d2830354", null ],
    [ "cppu::detail::getTypeFromTypeDescriptionReference", "a00541.html#a7ad6231b157a96f5425fbf3b668b2330", null ]
];

==> libreoffice-still-sdk-25.2.7-6-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/a00311.js <==
var a00311 =
[
    [ "cppu::UnoType&lt; T &gt;", "a01014.html", "a01014" ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a2a5e69a5a7c20b9675e7de52c674c74f", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a484a7f1ab147ff31d905fe25043ba927", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a02973029e5803f67e2f505db228f1800", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a8e9a83dbbdbe424b9e026ad4c94c79f3", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a08bcf546041af2abc08b1cc0a6e4a28e", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a8870b802ccf2d3760fd691f704a3c88b", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a8fdad5e906b1a6418a0d12df6a0cb447", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#abc66fa74095803f4c99f09cecec9fb11", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a2e9866b0e88e1ef623545f3c20509d81", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a980ac7c01ad8ee65a3ca5134957429f0", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a04eacc9c558d87087af3dd42a62f8aa1", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a3d68cd6a0dce2d1e13b59d4d02f3f0af", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#acf4ffa893ccd35be9b49c4c49dce7ca8", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a46d524c85268a20f98e56d7b0a923389", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a2d3a5b37a84942d51f91f48f49e957db", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#ad86b73560eae9fe41657992fb3931b18", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a728d989cc756ae6108398cfdc57488ab", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a6d93904d90e786a200012ad5c44ba2ad", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a9407c7520634f54fe5972ffcdff3ec64", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a01be54634084231c8a8d42a35bc11bbd", null ],
    [ "cppu::detail::cppu_detail_getUnoType", "a00541.html#a900a714bf1977628240aecbe89284c4e", null ],
    [ "cppu::getTypeFavourUnsigned", "a00537.html#a537248b31d476a5a671ecf9e175cb99e", null ],
    [ "cppu::getTypeFavourUnsigned", "a00537.html#a88763f57277570861901089a48dbfffe", null ],
    [ "cppu::getTypeFavourUnsigned", "a00537.html#a58d960508ebd9effe3f954872ec2ebaf", null ],
    [ "cppu::detail::getTypeFromTypeClass", "a00541.html#acb58f90e3da82a306b5eb7d4d2830354", null ],
    [ "cppu::detail::getTypeFromTypeDescriptionReference", "a00541.html#a7ad6231b157a96f5425fbf3b668b2330", null ]
];
